CA06-Cl01
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Portal links |
clickAndWait | link=Añadir portal link |
type | id_name_es | Portal Link CA06-Cl01
select | id_category | label=Primary link
type | id_slug | portal-link-ca06-cl01
clickAndWait | _save |
verifyText | link=Portal Link CA06-Cl01 | Portal Link CA06-Cl01
clickAndWait | link=Portal Link CA06-Cl01 |
clickAndWait | link=Borrar |
clickAndWait | //input[@value='Sí, estoy seguro'] |
clickAndWait | link=Terminar sesión |